Event Logger
==============================
![PyPI - Python Version](https://img.shields.io/pypi/pyversions/event-logger?style=plastic)
![PyPI](https://img.shields.io/pypi/v/event-logger?color=informational&style=plastic)

Upload dummy package to PyPI in order to demonstrate dependency confusion attack.

